@@ -385,19 +385,6 @@ sub setglobalvariables
     # Defaulting to native package format for epm
     
     if ( ! $installer::globals::packageformat ) { $installer::globals::packageformat = "native"; }
-            
-    # $installer::globals::servicesrdb_can_be_created can only be set, if regcomp (regcomp.exe) can be executed.
-        
-    if ( $installer::globals::iswin && $installer::globals::iswindowsbuild ) { $installer::globals::servicesrdb_can_be_created = 1; }
-    if ( $installer::globals::islinux && $installer::globals::islinuxbuild ) { $installer::globals::servicesrdb_can_be_created = 1; }
-    if ( $installer::globals::issolaris && $installer::globals::issolarisbuild ) { $installer::globals::servicesrdb_can_be_created = 1; }
-
-    # ToDo: Needs to be expanded for additional compiler (setting $installer::globals::servicesrdb_can_be_created = 1 for all external platforms)
-
-    if ((!($installer::globals::iswindowsbuild)) && (!($installer::globals::islinuxbuild)) && (!($installer::globals::issolarisbuild)))
-    {
-        $installer::globals::servicesrdb_can_be_created = 1;
-    }
 
     # extension, if $installer::globals::pro is set
     if ($installer::globals::pro) { $installer::globals::productextension = ".pro"; }
@@ -456,8 +443,7 @@ sub setglobalvariables
 
         if ( $installer::globals::compiler =~ /^unxmac/ )
         {
-            my $localcall = "chmod 777 $installer::globals::temppath \>\/dev\/null 2\>\&1";
-            system($localcall);
+            chmod 0777, $installer::globals::temppath;
         }
 
         $installer::globals::temppath = $installer::globals::temppath . $installer::globals::separator . "i";
@@ -656,8 +642,6 @@ sub outputparameter
     if ( $installer::globals::debian ) { push(@output, "Linux: Creating Debian packages\n"); }
     if ( $installer::globals::dounzip ) { push(@output, "Unzip ARCHIVE files\n"); }
     else  { push(@output, "Not unzipping ARCHIVE files\n"); }
-    if ( $installer::globals::servicesrdb_can_be_created ) { push(@output, "services.rdb can be created\n"); }
-    else  { push(@output, "services.rdb cannot be created !\n"); }
     if (!($installer::globals::languages_defined_in_productlist))
     {
         push(@output, "Languages:\n");
