@@ -76,20 +76,81 @@ sub overwrite_programfilesfolder
     }
 }
 
+##############################################################
+# Maximum length of directory name is 72.
+# Taking care of underlines, which are the separator.
+##############################################################
+
+sub make_short_dir_version
+{
+    my ($longstring, $length, $displayname) = @_;
+    
+    my $shortstring = "";
+    my $infoline = "";
+    my $savestring = $longstring;
+    
+    # Splitting the string at each "underline" and allowing only $length characters per directory name.
+    # Checking also uniqueness and length.
+    
+    my $stringarray = installer::converter::convert_stringlist_into_array_without_newline(\$longstring, "_");
+    
+    foreach my $onestring ( @{$stringarray} )
+    {
+        my $partstring = "";
+        
+        if ( $onestring =~ /\-/ )
+        {
+            my $localstringarray = installer::converter::convert_stringlist_into_array_without_newline(\$onestring, "-");
+            foreach my $onelocalstring ( @{$localstringarray} )
+            {
+                if ( length($onelocalstring) > $length ) { $onelocalstring = substr($onelocalstring, 0, $length); }
+                $partstring = $partstring . "-" . $onelocalstring;
+            }
+            $partstring =~ s/^\s*\-//;
+        }
+        else
+        {
+            if ( length($onestring) > $length ) { $partstring = substr($onestring, 0, $length); }
+            else { $partstring = $onestring; }
+        }
+
+        $shortstring = $shortstring . "_" . $partstring;
+    }
+
+    $shortstring =~ s/^\s*\_//;
+
+    if ( length($shortstring) > 72 )
+    {
+        my $shortlength = length($shortstring);
+        $infoline = "WARNING: Failed to create unique directory name with less than 72 characters: \"$displayname\" ($shortstring ($shortlength)).\n"; 
+        push(@installer::globals::logfileinfo, $infoline);
+    }
+
+    return $shortstring;
+}
+
 ##############################################################
 # Adding unique directory names to the directory collection
 ##############################################################
 
+my $already_checked_the_frigging_directories_for_uniqueness = 0;
+
 sub create_unique_directorynames
 {
-    my ($directoryref) = @_;
+    my ($directoryref, $allvariables) = @_;
 
     $installer::globals::officeinstalldirectoryset = 0;
+    
+    my %conversionhash = ();
+    my $infoline = "";
+    my $errorcount = 0;
 
     for ( my $i = 0; $i <= $#{$directoryref}; $i++ )
     {
         my $onedir = ${$directoryref}[$i];
-        my $uniquename = $onedir->{'HostName'};
+        my $hostname = $onedir->{'HostName'};
+
+        my $uniquename = $hostname;
         my $styles = "";
         if ( $onedir->{'Styles'} ) { $styles = $onedir->{'Styles'}; }
         # get_path_from_fullqualifiedname(\$uniqueparentname);
@@ -101,6 +162,44 @@ sub create_unique_directorynames
         $uniquename =~ s/\_//g;					# removing existing underlines
         $uniquename =~ s/\.//g;					# removing dots in directoryname
         $uniquename =~ s/\Q$installer::globals::separator\E/\_/g;	# replacing slash and backslash with underline
+        $uniquename =~ s/OpenOffice/OO/g;
+        $uniquename =~ s/LibreOffice/LO/g;
+        $uniquename =~ s/_registry/_rgy/g;
+        $uniquename =~ s/_registration/_rgn/g;
+        $uniquename =~ s/_extension/_ext/g;
+        $uniquename =~ s/_frame/_frm/g;
+        $uniquename =~ s/_table/_tbl/g;
+        $uniquename =~ s/_chart/_crt/g;
+
+        my $startlength = 5;
+        
+        if ( ! $allvariables->{'NOSHORTDIRECTORYNAMES'} )
+        {
+            # This process does not work for SDK, because of its long and similar pathes
+            $uniquename = make_short_dir_version($uniquename, $startlength, $hostname); # taking care of underlines!
+        }
+
+        if ( !$already_checked_the_frigging_directories_for_uniqueness &&
+	     exists($installer::globals::alluniquedirectorynames{$uniquename}) )
+        {
+            # This is an error, that must stop the packaging process
+            $errorcount++;
+
+            $infoline = "$errorcount: Already existing unique directory: $uniquename\n";
+            push( @installer::globals::logfileinfo, $infoline);
+            $infoline = "$errorcount: First full directory: $conversionhash{$uniquename}\n";
+            push( @installer::globals::logfileinfo, $infoline);
+            $infoline = "$errorcount: Current full directory: $hostname\n";
+            push( @installer::globals::logfileinfo, $infoline);		
+        }
+    
+        $conversionhash{$uniquename} = $hostname;
+
+        $installer::globals::alluniquedirectorynames{$uniquename} = 1;
+
+        # Important: The unique parent is generated from the string $uniquename. Therefore counters
+        # like adding "_1" is not allowed to achive uniqueness, because this depends from other directories
+        # and does not deliver always the same result.
 
         my $uniqueparentname = $uniquename;
 
@@ -146,6 +245,11 @@ sub create_unique_directorynames
             $installer::globals::vendordirectory = $uniquename;
             $installer::globals::vendordirectoryset = 1;
         }
+    }
+    
+    if ( $errorcount > 0 )
+    {
+        installer::exiter::exit_program("ERROR: Failed to create unique directory names.", "create_unique_directorynames");	
     }			
 }
 
@@ -160,6 +264,7 @@ sub check_sourcedir_addon
     if (($installer::globals::addchildprojects) ||
         ($installer::globals::patch) ||
         ($installer::globals::languagepack) || 
+        ($installer::globals::helppack) || 
         ($allvariableshashref->{'CHANGETARGETDIR'}))
     {
         my $sourcediraddon = "\:\.";
@@ -235,7 +340,6 @@ sub create_defaultdir_directorynames
 
         $hostname =~ s/\Q$installer::globals::separator\E\s*$//;	
         get_last_directory_name(\$hostname);
-        # installer::pathanalyzer::make_absolute_filename_to_relative_filename(\$hostname);	# making program/classes to classes
         my $uniquename = $onedir->{'uniquename'};
         my $shortstring;
         if (( $installer::globals::updatedatabase ) && ( exists($shortdirnamehashref->{$uniquename}) ))
@@ -308,22 +412,18 @@ sub create_directorytable_from_collection
 
 sub add_root_directories
 {
-    my ($directorytableref, $allvariableshashref) = @_;
+    my ($directorytableref, $allvariableshashref, $onelanguage) = @_;
     
-#	my $sourcediraddon = "";
-#	if (($installer::globals::addchildprojects) ||
-#		($installer::globals::patch) ||
-#		($installer::globals::languagepack) || 
-#		($allvariableshashref->{'CHANGETARGETDIR'}))
-#	{
-#		$sourcediraddon = "\:\.";
-#	}
-
     my $oneline = "";
 
-    if (( ! $installer::globals::patch ) && ( ! $installer::globals::languagepack ) && ( ! $allvariableshashref->{'DONTUSESTARTMENUFOLDER'} ))
+    if (( ! $installer::globals::patch ) && ( ! $installer::globals::languagepack ) && ( ! $installer::globals::helppack ) && ( ! $allvariableshashref->{'DONTUSESTARTMENUFOLDER'} ))
     {
-        my $productname = $allvariableshashref->{'PRODUCTNAME'};
+        my $productname;
+
+	$productname = $allvariableshashref->{'PRODUCTNAME'};
+	if ($onelanguage eq 'pt-BR' && defined $allvariableshashref->{'PRODUCTNAME_BR'}) {
+	    $productname = $allvariableshashref->{'PRODUCTNAME_BR'};
+	}
         my $productversion = $allvariableshashref->{'PRODUCTVERSION'};
         my $baseproductversion = $productversion;
 
@@ -426,7 +526,7 @@ sub add_root_directories
 
 sub create_directory_table
 {
-    my ($directoryref, $basedir, $allvariableshashref, $shortdirnamehashref, $loggingdir) = @_;
+    my ($directoryref, $languagesarrayref, $basedir, $allvariableshashref, $shortdirnamehashref, $loggingdir) = @_;
 
     # Structure of the directory table:
     # Directory Directory_Parent DefaultDir
@@ -436,27 +536,34 @@ sub create_directory_table
     # Before ":" : [sourcedir]:[destdir] (not programmed yet)
     # After ":" : 8+3 and not 8+3 the destination directory name
 
+    for ( my $m = 0; $m <= $#{$languagesarrayref}; $m++ )
+    {
+        my $onelanguage = ${$languagesarrayref}[$m];
+        $installer::globals::installlocationdirectoryset = 0;
+
     my @directorytable = ();
     my $infoline;
     
     overwrite_programfilesfolder($allvariableshashref);
-    create_unique_directorynames($directoryref);
     if ( $installer::globals::globallogging ) { installer::files::save_array_of_hashes($loggingdir . "directoriesforidt_local_1.log", $directoryref); }
+    create_unique_directorynames($directoryref, $allvariableshashref);
+    $already_checked_the_frigging_directories_for_uniqueness++;
+    if ( $installer::globals::globallogging ) { installer::files::save_array_of_hashes($loggingdir . "directoriesforidt_local_1a.log", $directoryref); }
     create_defaultdir_directorynames($directoryref, $shortdirnamehashref);	# only destdir!
     if ( $installer::globals::globallogging ) { installer::files::save_array_of_hashes($loggingdir . "directoriesforidt_local_2.log", $directoryref); }
     set_installlocation_directory($directoryref, $allvariableshashref);
     if ( $installer::globals::globallogging ) { installer::files::save_array_of_hashes($loggingdir . "directoriesforidt_local_3.log", $directoryref); }
     installer::windows::idtglobal::write_idt_header(\@directorytable, "directory");
-    add_root_directories(\@directorytable, $allvariableshashref);
+    add_root_directories(\@directorytable, $allvariableshashref, $onelanguage);
     create_directorytable_from_collection(\@directorytable, $directoryref);
 
     # Saving the file
 
-    my $directorytablename = $basedir . $installer::globals::separator . "Director.idt";
+    my $directorytablename = $basedir . $installer::globals::separator . "Director.idt" . "." . $onelanguage;
     installer::files::save_file($directorytablename ,\@directorytable);
     $infoline = "Created idt file: $directorytablename\n"; 
     push(@installer::globals::logfileinfo, $infoline);
-
+    }
 }
 
 1;
