@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /* $XConsortium: parse.c,v 1.30 94/04/17 20:10:38 gildea Exp $ */
 /*
 
@@ -346,7 +347,7 @@ int deftype (line, filep, file_red, file, parse_it, symbols)
         /*
          * copy the definition back to the beginning of the line.
          */
-        strcpy (line, p);
+        memmove (line, p, strlen(p));
         break;
     case ELSE:
     case ENDIF:
@@ -419,14 +420,12 @@ static int hash( str )
 {
     /* Hash (Kernighan and Ritchie) */
     register unsigned int hashval = 0;
-    //char *s = str;
 
     for ( ; *str; str++ )
     {
         hashval = ( hashval * SYMHASHSEED ) + ( *str );
     }
 
-    //fprintf( stderr, "hash: %s, %d\n", s, hashval & ( SYMHASHMEMBERS - 1 ) );
     return hashval & ( SYMHASHMEMBERS - 1 );
 }
 
@@ -612,3 +611,5 @@ void hash_undefine( symbol, symbols )
         }
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
